@@ -67,6 +67,14 @@ class NumericsSubFrame(PointSourceRendering):
         image_sub_frame = self._numerics_subframe.re_size_convolve(flux_array, unconvolved=unconvolved)
         return self._complete_frame(image_sub_frame)
 
+    @property
+    def grid_supersampling_factor(self):
+        """
+
+        :return: supersampling factor set for higher resolution sub-pixel sampling of surface brightness
+        """
+        return self._numerics_subframe.grid_supersampling_factor
+
     @property
     def coordinates_evaluate(self):
         """
@@ -75,6 +83,22 @@ class NumericsSubFrame(PointSourceRendering):
         """
         return self._numerics_subframe.coordinates_evaluate
 
+    @property
+    def convolution_class(self):
+        """
+
+        :return: convolution class (can be SubgridKernelConvolution, PixelKernelConvolution, MultiGaussianConvolution, ...)
+        """
+        return self._numerics_subframe.convolution_class
+
+    @property
+    def grid_class(self):
+        """
+
+        :return: grid class (can be RegularGrid, AdaptiveGrid)
+        """
+        return self._numerics_subframe.grid_class
+
     def _complete_frame(self, image_sub_frame):
         """
         :param image_sub_frame: 2d numpy array of size of the sub-frame
