@@ -11,21 +11,22 @@ class EPL(LensProfileBase):
     """
     Elliptical Power Law
     kappa = (2-t)/2*(b/r)^t
+    where t = gamma - 1
     """
-    param_names = ['theta_E', 'e1', 'e2', 't', 'center_x', 'center_y']
-    lower_limit_default = {'theta_E': 0, 'e1': -0.5, 'e2': -0.5, 't': 0, 'center_x': -100, 'center_y': -100}
-    upper_limit_default = {'theta_E': 10, 'e1': 0.5, 'e2': -0.5, 't': 2, 'center_x': 100, 'center_y': 100}
+    param_names = ['theta_E', 'e1', 'e2', 'gamma', 'center_x', 'center_y']
+    lower_limit_default = {'theta_E': 0, 'e1': -0.5, 'e2': -0.5, 'gamma': 0, 'center_x': -100, 'center_y': -100}
+    upper_limit_default = {'theta_E': 10, 'e1': 0.5, 'e2': 0.5, 'gamma': 2, 'center_x': 100, 'center_y': 100}
 
     def __init__(self):
         self.epl_major_axis = EPLMajorAxis()
         super(EPL, self).__init__()
 
-    def param_conv(self, theta_E, e1, e2, t):
+    def param_conv(self, theta_E, e1, e2, gamma):
         if self._static is True:
             return self._b_static, self._t_static, self._q_static, self._phi_G_static
-        return self._param_conv(theta_E, e1, e2, t)
+        return self._param_conv(theta_E, e1, e2, gamma)
 
-    def _param_conv(self, theta_E, e1, e2, t):
+    def _param_conv(self, theta_E, e1, e2, gamma):
         """
         convert parameters from R = r sqrt(1 − e*cos(2*phi)) to
         R = sqrt(q^2 x^2 + y^2)
@@ -40,9 +41,10 @@ class EPL(LensProfileBase):
         phi_G, q = param_util.ellipticity2phi_q(e1, e2)
         theta_E_conv = self._theta_E_q_convert(theta_E, q)
         b = theta_E_conv * np.sqrt((1 + q**2)/2)
+        t = gamma - 1
         return b, t, q, phi_G
 
-    def set_static(self, theta_E, e1, e2, t, center_x=0, center_y=0):
+    def set_static(self, theta_E, e1, e2, gamma, center_x=0, center_y=0):
         """
 
         :param x: x-coordinate in image plane
@@ -56,7 +58,7 @@ class EPL(LensProfileBase):
         :return: self variables set
         """
         self._static = True
-        self._b_static, self._t_static, self._q_static, self._phi_G_static = self._param_conv(theta_E, e1, e2, t)
+        self._b_static, self._t_static, self._q_static, self._phi_G_static = self._param_conv(theta_E, e1, e2, gamma)
 
     def set_dynamic(self):
         """
@@ -73,7 +75,7 @@ class EPL(LensProfileBase):
         if hasattr(self, '_q_static'):
             del self._q_static
 
-    def function(self, x, y, theta_E, e1, e2, t, center_x=0, center_y=0):
+    def function(self, x, y, theta_E, e1, e2, gamma, center_x=0, center_y=0):
         """
 
         :param x: x-coordinate in image plane
@@ -86,7 +88,7 @@ class EPL(LensProfileBase):
         :param center_y: profile center
         :return: lensing potential
         """
-        b, t, q, phi_G = self.param_conv(theta_E, e1, e2, t)
+        b, t, q, phi_G = self.param_conv(theta_E, e1, e2, gamma)
         # shift
         x_ = x - center_x
         y_ = y - center_y
@@ -97,7 +99,7 @@ class EPL(LensProfileBase):
         # rotate back
         return f_
 
-    def derivatives(self, x, y, theta_E, e1, e2, t, center_x=0, center_y=0):
+    def derivatives(self, x, y, theta_E, e1, e2, gamma, center_x=0, center_y=0):
         """
 
         :param x: x-coordinate in image plane
@@ -110,7 +112,7 @@ class EPL(LensProfileBase):
         :param center_y: profile center
         :return: alpha_x, alpha_y
         """
-        b, t, q, phi_G = self.param_conv(theta_E, e1, e2, t)
+        b, t, q, phi_G = self.param_conv(theta_E, e1, e2, gamma)
         # shift
         x_ = x - center_x
         y_ = y - center_y
@@ -122,7 +124,7 @@ class EPL(LensProfileBase):
         f_x, f_y = util.rotate(f__x, f__y, -phi_G)
         return f_x, f_y
 
-    def hessian(self, x, y, theta_E, e1, e2, t, center_x=0, center_y=0):
+    def hessian(self, x, y, theta_E, e1, e2, gamma, center_x=0, center_y=0):
         """
 
         :param x: x-coordinate in image plane
@@ -135,7 +137,8 @@ class EPL(LensProfileBase):
         :param center_y: profile center
         :return: f_xx, f_yy, f_xy
         """
-        b, t, q, phi_G = self.param_conv(theta_E, e1, e2, t)
+
+        b, t, q, phi_G = self.param_conv(theta_E, e1, e2, gamma)
         # shift
         x_ = x - center_x
         y_ = y - center_y
@@ -174,7 +177,7 @@ class EPLMajorAxis(LensProfileBase):
     elliptical power law.
 
     kappa = (2-t)/2 * [b/sqrt(q^2 x^2 + y^2)]^t
-
+    where t = gamma - 1 (from EPL class)
     Tessore & Metcalf (2015), https://arxiv.org/abs/1507.01819
     """
     param_names = ['b', 't', 'q', 'center_x', 'center_y']
