@@ -13,7 +13,7 @@ class NIE(LensProfileBase):
     """
     param_names = ['theta_E', 'e1', 'e2', 's_scale', 'center_x', 'center_y']
     lower_limit_default = {'theta_E': 0, 'e1': -0.5, 'e2': -0.5, 's_scale': 0, 'center_x': -100, 'center_y': -100}
-    upper_limit_default = {'theta_E': 10, 'e1': 0.5, 'e2': -0.5, 's_scale': 100, 'center_x': 100, 'center_y': 100}
+    upper_limit_default = {'theta_E': 10, 'e1': 0.5, 'e2': 0.5, 's_scale': 100, 'center_x': 100, 'center_y': 100}
 
     def __init__(self):
         self.nie_major_axis = NIEMajorAxis()
@@ -172,8 +172,11 @@ class NIE(LensProfileBase):
 class NIEMajorAxis(LensProfileBase):
     """
     This class contains the function and the derivatives of the non-singular isothermal ellipse.
-    See Keeton&Kochanek 1998, https://arxiv.org/pdf/astro-ph/9705194.pdf
-    kappa =  b *(q2(s2 + x2) + y2􏰉)−1/2
+    See Keeton and Kochanek 1998, https://arxiv.org/pdf/astro-ph/9705194.pdf
+
+    .. math::
+        \kappa =  b *(q2(s2 + x2) + y2􏰉)^{−1/2}`
+
     """
 
     param_names = ['b', 's', 'q', 'center_x', 'center_y']
