@@ -1,16 +1,14 @@
 __author__ = 'sibirrer'
 
-#file which contains class for lens model routines
 import numpy as np
 from lenstronomy.LensModel.profile_list_base import ProfileListBase
 
 
 class SinglePlane(ProfileListBase):
     """
-    class to handle an arbitrary list of lens models
+    class to handle an arbitrary list of lens models in a single lensing plane
     """
 
-
     def ray_shooting(self, x, y, kwargs, k=None):
         """
         maps image to source position (inverse deflection)
@@ -25,7 +23,7 @@ class SinglePlane(ProfileListBase):
         dx, dy = self.alpha(x, y, kwargs, k=k)
         return x - dx, y - dy
 
-    def fermat_potential(self, x_image, y_image, x_source, y_source, kwargs_lens, k=None):
+    def fermat_potential(self, x_image, y_image, kwargs_lens, x_source=None, y_source=None, k=None):
         """
         fermat potential (negative sign means earlier arrival time)
 
@@ -38,6 +36,8 @@ class SinglePlane(ProfileListBase):
         """
 
         potential = self.potential(x_image, y_image, kwargs_lens, k=k)
+        if x_source is None or y_source is None:
+            x_source, y_source = self.ray_shooting(x_image, y_image, kwargs_lens, k=k)
         geometry = ((x_image - x_source)**2 + (y_image - y_source)**2) / 2.
         return geometry - potential
 
@@ -120,6 +120,10 @@ class SinglePlane(ProfileListBase):
         """
         computes the mass within a 3d sphere of radius r
 
+        if you want to have physical units of kg, you need to multiply by this factor:
+        const.arcsec ** 2 * self._cosmo.dd * self._cosmo.ds / self._cosmo.dds * const.Mpc * const.c ** 2 / (4 * np.pi * const.G)
+        grav_pot = -const.G * mass_dim / (r * const.arcsec * self._cosmo.dd * const.Mpc)
+
         :param r: radius (in angular units)
         :param kwargs: list of keyword arguments of lens model parameters matching the lens model classes
         :param bool_list: list of bools that are part of the output
@@ -132,8 +136,6 @@ class SinglePlane(ProfileListBase):
                 kwargs_i = {k:v for k, v in kwargs[i].items() if not k in ['center_x', 'center_y']}
                 mass_3d_i = func.mass_3d_lens(r, **kwargs_i)
                 mass_3d += mass_3d_i
-                #except:
-                #    raise ValueError('Lens profile %s does not support a 3d mass function!' % self.model_list[i])
         return mass_3d
 
     def mass_2d(self, r, kwargs, bool_list=None):
@@ -152,6 +154,23 @@ class SinglePlane(ProfileListBase):
                 kwargs_i = {k: v for k, v in kwargs[i].items() if not k in ['center_x', 'center_y']}
                 mass_2d_i = func.mass_2d_lens(r, **kwargs_i)
                 mass_2d += mass_2d_i
-                #except:
-                #    raise ValueError('Lens profile %s does not support a 2d mass function!' % self.model_list[i])
         return mass_2d
+
+    def density(self, r, kwargs, bool_list=None):
+        """
+        3d mass density at radius r
+        The integral in the LOS projection of this quantity results in the convergence quantity.
+
+        :param r: radius (in angular units)
+        :param kwargs: list of keyword arguments of lens model parameters matching the lens model classes
+        :param bool_list: list of bools that are part of the output
+        :return: mass density at radius r (in angular units, modulo epsilon_crit)
+        """
+        bool_list = self._bool_list(bool_list)
+        density = 0
+        for i, func in enumerate(self.func_list):
+            if bool_list[i] is True:
+                kwargs_i = {k: v for k, v in kwargs[i].items() if not k in ['center_x', 'center_y']}
+                density_i = func.density_lens(r, **kwargs_i)
+                density += density_i
+        return density
