@@ -6,30 +6,26 @@ from lenstronomy.PointSource.point_source_types import PointSourceCached
 class PointSource(object):
 
     def __init__(self, point_source_type_list, lensModel=None, fixed_magnification_list=None,
-                 additional_images_list=None, magnification_limit=None,
-                 save_cache=False, min_distance=0.05, search_window=5, precision_limit=10**(-10), num_iter_max=100,
-                 x_center=0, y_center=0):
+                 additional_images_list=None, flux_from_point_source_list=None, magnification_limit=None,
+                 save_cache=False, kwargs_lens_eqn_solver=None):
         """
-
+        min_distance=0.05, search_window=5, precision_limit=10**(-10), num_iter_max=100,
+                 x_center=0, y_center=0):
         :param point_source_type_list: list of point source types
         :param lensModel: instance of the LensModel() class
         :param fixed_magnification_list: list of bools (same length as point_source_type_list). If True, magnification
         ratio of point sources is fixed to the one given by the lens model
         :param additional_images_list: list of bools (same length as point_source_type_list). If True, search for
         additional images of the same source is conducted.
+        :param flux_from_point_source_list: list of bools (optional), if set, will only return image positions
+         (for imaging modeling) for the subset of the point source lists that =True. This option enables to model
         :param magnification_limit: float >0 or None, if float is set and additional images are computed, only those
-        images will be computed that exceed the lensing magnification (absolute value) limit
+         images will be computed that exceed the lensing magnification (absolute value) limit
         :param save_cache: bool, saves image positions and only if delete_cache is executed, a new solution of the lens
-        equation is conducted with the lens model parameters provided. This can increase the speed as multiple times the
-        image positions are requested for the same lens model. Attention in usage!
-        :param min_distance: float, minimum initial search grid for image positions when solving the lens equation.
-        Image separations below this scale will not be found.
-        :param search_window: window size of the image position search with the lens equation solver.
-        Please adopt when dealing with wider separation image positions!
-        :param precision_limit: see LensEquationSolver() instance
-        :param num_iter_max: see LensEquationSolver() instance
-        :param x_center: center of search window
-        :param y_center: center of search window
+         equation is conducted with the lens model parameters provided. This can increase the speed as multiple times the
+         image positions are requested for the same lens model. Attention in usage!
+        :param kwargs_lens_eqn_solver: keyword arguments specifying the numerical settings for the lens equation solver
+         see LensEquationSolver() class for details
 
         for the parameters: min_distance=0.01, search_window=5, precision_limit=10**(-10), num_iter_max=100
         have a look at the lensEquationSolver class
@@ -43,6 +39,9 @@ class PointSource(object):
         self._fixed_magnification_list = fixed_magnification_list
         if additional_images_list is None:
             additional_images_list = [False] * len(point_source_type_list)
+        if flux_from_point_source_list is None:
+            flux_from_point_source_list = [True] * len(point_source_type_list)
+        self._flux_from_point_source_list = flux_from_point_source_list
         for i, model in enumerate(point_source_type_list):
             if model == 'UNLENSED':
                 from lenstronomy.PointSource.point_source_types import Unlensed
@@ -58,10 +57,13 @@ class PointSource(object):
                                                                  save_cache=save_cache))
             else:
                 raise ValueError("Point-source model %s not available" % model)
-        self._min_distance, self._search_window, self._precision_limit, self._num_iter_max, self._x_center, self._y_center, self._magnification_limit = min_distance, search_window, precision_limit, num_iter_max, x_center, y_center, magnification_limit
+        if kwargs_lens_eqn_solver is None:
+            kwargs_lens_eqn_solver = {}
+        self._kwargs_lens_eqn_solver = kwargs_lens_eqn_solver
+        self._magnification_limit = magnification_limit
         self._save_cache = save_cache
 
-    def update_search_window(self, search_window, x_center, y_center, min_distance=None):
+    def update_search_window(self, search_window, x_center, y_center, min_distance=None, only_from_unspecified=False):
         """
         update the search area for the lens equation solver
 
@@ -69,11 +71,19 @@ class PointSource(object):
         :param x_center: center of search window
         :param y_center: center of search window
         :param min_distance: minimum search distance
+        :param only_from_unspecified: bool, if True, only sets keywords that previously have not been set
         :return: updated self instances
         """
-        if min_distance is not None:
-            self._min_distance = min_distance
-        self._search_window, self._x_center, self._y_center = search_window, x_center, y_center
+        if min_distance is not None and not (hasattr(self._kwargs_lens_eqn_solver, 'min_distance') and only_from_unspecified):
+            self._kwargs_lens_eqn_solver['min_distance'] = min_distance
+        if only_from_unspecified:
+            self._kwargs_lens_eqn_solver['search_window'] = self._kwargs_lens_eqn_solver.get('search_window', search_window)
+            self._kwargs_lens_eqn_solver['x_center'] = self._kwargs_lens_eqn_solver.get('x_center', x_center)
+            self._kwargs_lens_eqn_solver['y_center'] = self._kwargs_lens_eqn_solver.get('y_center', y_center)
+        else:
+            self._kwargs_lens_eqn_solver['search_window'] = search_window
+            self._kwargs_lens_eqn_solver['x_center'] = x_center
+            self._kwargs_lens_eqn_solver['y_center'] = y_center
 
     def update_lens_model(self, lens_model_class):
         """
@@ -151,11 +161,9 @@ class PointSource(object):
                 if original_position is True and self.point_source_type_list[i] == 'LENSED_POSITION':
                     x_image, y_image = kwargs['ra_image'], kwargs['dec_image']
                 else:
-                    x_image, y_image = model.image_position(kwargs, kwargs_lens, min_distance=self._min_distance,
-                                                        search_window=self._search_window,
-                                                        precision_limit=self._precision_limit,
-                                                        num_iter_max=self._num_iter_max, x_center=self._x_center,
-                                                        y_center=self._y_center, magnification_limit=self._magnification_limit)
+                    x_image, y_image = model.image_position(kwargs, kwargs_lens,
+                                                            magnification_limit=self._magnification_limit,
+                                                            kwargs_lens_eqn_solver=self._kwargs_lens_eqn_solver)
                 x_image_list.append(x_image)
                 y_image_list.append(y_image)
         return x_image_list, y_image_list
@@ -195,10 +203,11 @@ class PointSource(object):
         n = 0
         ra_pos_list, dec_pos_list = self.image_position(kwargs_ps, kwargs_lens)
         for i, model in enumerate(self.point_source_type_list):
-            if self._fixed_magnification_list[i]:
-                n += 1
-            else:
-                n += len(ra_pos_list[i])
+            if self._flux_from_point_source_list[i]:
+                if self._fixed_magnification_list[i]:
+                    n += 1
+                else:
+                    n += len(ra_pos_list[i])
         return n
 
     def image_amplitude(self, kwargs_ps, kwargs_lens, k=None):
@@ -211,12 +220,9 @@ class PointSource(object):
         """
         amp_list = []
         for i, model in enumerate(self._point_source_list):
-            if k is None or k == i:
-                amp_list.append(model.image_amplitude(kwargs_ps=kwargs_ps[i], kwargs_lens=kwargs_lens, min_distance=self._min_distance,
-                                                        search_window=self._search_window,
-                                                        precision_limit=self._precision_limit,
-                                                        num_iter_max=self._num_iter_max, x_center=self._x_center,
-                                                        y_center=self._y_center))
+            if (k is None or k == i) and self._flux_from_point_source_list[i]:
+                amp_list.append(model.image_amplitude(kwargs_ps=kwargs_ps[i], kwargs_lens=kwargs_lens,
+                                                      kwargs_lens_eqn_solver=self._kwargs_lens_eqn_solver))
         return amp_list
 
     def source_amplitude(self, kwargs_ps, kwargs_lens):
@@ -229,15 +235,18 @@ class PointSource(object):
         """
         amp_list = []
         for i, model in enumerate(self._point_source_list):
-            amp_list.append(model.source_amplitude(kwargs_ps=kwargs_ps[i], kwargs_lens=kwargs_lens))
+            if self._flux_from_point_source_list[i]:
+                amp_list.append(model.source_amplitude(kwargs_ps=kwargs_ps[i], kwargs_lens=kwargs_lens))
         return amp_list
 
     def linear_response_set(self, kwargs_ps, kwargs_lens=None, with_amp=False):
         """
 
-        :param kwargs_ps:
-        :param kwargs_lens:
-        :return:
+        :param kwargs_ps: point source keyword argument list
+        :param kwargs_lens: lens model keyword argument list
+        :param with_amp: bool, if True returns the image amplitude derived from kwargs_ps,
+         otherwise the magnification of the lens model
+        :return: ra_pos, dec_pos, amp, n
         """
         ra_pos = []
         dec_pos = []
@@ -245,26 +254,27 @@ class PointSource(object):
         self._set_save_cache(True)
         x_image_list, y_image_list = self.image_position(kwargs_ps, kwargs_lens)
         for i, model in enumerate(self._point_source_list):
-            x_pos = x_image_list[i]
-            y_pos = y_image_list[i]
-            if self._fixed_magnification_list[i]:
-                ra_pos.append(list(x_pos))
-                dec_pos.append(list(y_pos))
-                if with_amp:
-                    mag = self.image_amplitude(kwargs_ps, kwargs_lens, k=i)[0]
+            if self._flux_from_point_source_list[i]:
+                x_pos = x_image_list[i]
+                y_pos = y_image_list[i]
+                if self._fixed_magnification_list[i]:
+                    ra_pos.append(list(x_pos))
+                    dec_pos.append(list(y_pos))
+                    if with_amp:
+                        mag = self.image_amplitude(kwargs_ps, kwargs_lens, k=i)[0]
+                    else:
+                        mag = self._lensModel.magnification(x_pos, y_pos, kwargs_lens)
+                        mag = np.abs(mag)
+                    amp.append(list(mag))
                 else:
-                    mag = self._lensModel.magnification(x_pos, y_pos, kwargs_lens)
-                    mag = np.abs(mag)
-                amp.append(list(mag))
-            else:
-                if with_amp:
-                    mag = self.image_amplitude(kwargs_ps, kwargs_lens, k=i)[0]
-                else:
-                    mag = np.ones_like(x_pos)
-                for j in range(len(x_pos)):
-                    ra_pos.append([x_pos[j]])
-                    dec_pos.append([y_pos[j]])
-                    amp.append([mag[j]])
+                    if with_amp:
+                        mag = self.image_amplitude(kwargs_ps, kwargs_lens, k=i)[0]
+                    else:
+                        mag = np.ones_like(x_pos)
+                    for j in range(len(x_pos)):
+                        ra_pos.append([x_pos[j]])
+                        dec_pos.append([y_pos[j]])
+                        amp.append([mag[j]])
         n = len(ra_pos)
         if self._save_cache is False:
             self.delete_lens_model_cache()
@@ -282,16 +292,15 @@ class PointSource(object):
         """
         ra_pos_list, dec_pos_list = self.image_position(kwargs_ps, kwargs_lens)
         for k, model in enumerate(self._point_source_list):
-            kwargs = kwargs_ps[k]
-            if self._fixed_magnification_list[k]:
-                kwargs['source_amp'] = param[i]
-                #mag = self._lensModel.magnification(ra_pos_list[k], dec_pos_list[k], kwargs_lens)
-                #kwargs['point_amp'] = np.abs(mag) * param[i]
-                i += 1
-            else:
-                n_points = len(ra_pos_list[k])
-                kwargs['point_amp'] = param[i:i + n_points]
-                i += n_points
+            if self._flux_from_point_source_list[k]:
+                kwargs = kwargs_ps[k]
+                if self._fixed_magnification_list[k]:
+                    kwargs['source_amp'] = param[i]
+                    i += 1
+                else:
+                    n_points = len(ra_pos_list[k])
+                    kwargs['point_amp'] = param[i:i + n_points]
+                    i += n_points
         return kwargs_ps, i
 
     def check_image_positions(self, kwargs_ps, kwargs_lens, tolerance=0.001):
@@ -324,12 +333,30 @@ class PointSource(object):
         """
         kwargs_list = copy.deepcopy(kwargs_ps)
         for i, model in enumerate(self.point_source_type_list):
-            amp = amp_list[i]
-            if model == 'UNLENSED':
-                kwargs_list[i]['point_amp'] = amp
-            elif model in ['LENSED_POSITION', 'SOURCE_POSITION']:
-                if self._fixed_magnification_list[i] is True:
-                    kwargs_list[i]['source_amp'] = amp
-                else:
+            if self._flux_from_point_source_list[i]:
+                amp = amp_list[i]
+                if model == 'UNLENSED':
                     kwargs_list[i]['point_amp'] = amp
+                elif model in ['LENSED_POSITION', 'SOURCE_POSITION']:
+                    if self._fixed_magnification_list[i] is True:
+                        kwargs_list[i]['source_amp'] = amp
+                    else:
+                        kwargs_list[i]['point_amp'] = amp
         return kwargs_list
+
+    @classmethod
+    def check_positive_flux(cls, kwargs_ps):
+        """
+        check whether inferred linear parameters are positive
+
+        :param kwargs_ps:
+        :return: bool
+        """
+        pos_bool = True
+        for kwargs in kwargs_ps:
+            point_amp = kwargs['point_amp']
+            for amp in point_amp:
+                if amp < 0:
+                    pos_bool = False
+                    break
+        return pos_bool
