@@ -19,7 +19,7 @@ Implementations of four different types of processing pools:
 
     - MPIPool: An MPI pool.
     - MultiPool: A multiprocessing for local parallelization.
-    - SerialPool: A serial pool, which uses the built-in ``map`` function
+    - SerialPool: A serial pool, which uses the built-in `map` function
 
 """
 
@@ -49,7 +49,6 @@ def choose_pool(mpi=False, processes=1, **kwargs):
     The requirement of schwimmbad relies on the master branch (as specified in requirements.txt).
     The 'use_dill' functionality can raise if not following the requirement specified.
 
-
     Choose between the different pools given options from, e.g., argparse.
 
     Parameters
@@ -60,11 +59,10 @@ def choose_pool(mpi=False, processes=1, **kwargs):
     processes : int, optional
         Use the multiprocessing pool,
         :class:`~schwimmbad.multiprocessing.MultiPool`, with this number of
-        processes. By default, ``processes=1``, will use the
-        :class:`~schwimmbad.serial.SerialPool`.
-    **kwargs
-        Any additional kwargs are passed in to the pool class initializer
-        selected by the arguments.
+        processes. By default, ``processes=1``, will use them:class:`~schwimmbad.serial.SerialPool`.
+
+    Any additional kwargs are passed in to the pool class initializer selected by the arguments.
+
     """
 
     if mpi:
