@@ -67,7 +67,8 @@ class Param(object):
                  joint_lens_light_with_point_source=[], joint_extinction_with_lens_light=[],
                  joint_lens_with_source_light=[], mass_scaling_list=None, point_source_offset=False,
                  num_point_source_list=None, image_plane_source_list=None, solver_type='NONE', Ddt_sampling=None,
-                 source_size=False, num_tau0=0):
+                 source_size=False, num_tau0=0, lens_redshift_sampling_indexes=None,
+                 source_redshift_sampling_indexes=None, source_grid_offset=False):
         """
 
         :param kwargs_model:
@@ -109,16 +110,38 @@ class Param(object):
         :param Ddt_sampling:
         :param source_size:
         :param num_tau0:
+        :param lens_redshift_sampling_indexes: list of integers corresponding to the lens model components whose redshifts
+         are a free parameter (only has an effect in multi-plane lensing) with same indexes indicating joint redshift,
+         in ascending numbering e.g. [-1, 0, 0, 1, 0, 2], -1 indicating not sampled fixed indexes
+        :param source_redshift_sampling_indexes: list of integers corresponding to the source model components whose redshifts
+         are a free parameter (only has an effect in multi-plane lensing) with same indexes indicating joint redshift,
+         in ascending numbering e.g. [-1, 0, 0, 1, 0, 2], -1 indicating not sampled fixed indexes. These indexes are
+         the sample as for the lens
+        :param source_grid_offset: optional, if True when using a pixel-based modelling (e.g. with STARLETS-like profiles),
+        adds two additional sampled parameters describing RA/Dec offsets between data coordinate grid and pixelated source plane coordinate grid.
         """
 
         self._lens_model_list = kwargs_model.get('lens_model_list', [])
+        self._lens_redshift_list = kwargs_model.get('lens_redshift_list', None)
         self._source_light_model_list = kwargs_model.get('source_light_model_list', [])
+        self._source_redshift_list = kwargs_model.get('source_redshift_list', None)
         self._lens_light_model_list = kwargs_model.get('lens_light_model_list', [])
         self._point_source_model_list = kwargs_model.get('point_source_model_list', [])
         self._optical_depth_model_list = kwargs_model.get('optical_depth_model_list', [])
+        self._kwargs_model = kwargs_model
 
-        lens_model_class, source_model_class, _, _, _ = class_creator.create_class_instances(all_models=True, **kwargs_model)
-        self._image2SourceMapping = Image2SourceMapping(lensModel=lens_model_class, sourceModel=source_model_class)
+        # check how many redshifts need to be sampled
+        num_z_sampling = 0
+        if lens_redshift_sampling_indexes is not None:
+            num_z_sampling = int(np.max(lens_redshift_sampling_indexes) + 1)
+        if source_redshift_sampling_indexes is not None:
+            num_z_source = int(np.max(source_redshift_sampling_indexes) + 1)
+            num_z_sampling = max(num_z_sampling, num_z_source)
+        self._num_z_sampling, self._lens_redshift_sampling_indexes, self._source_redshift_sampling_indexes = num_z_sampling, lens_redshift_sampling_indexes, source_redshift_sampling_indexes
+
+        self._lens_model_class, self._source_model_class, _, _, _ = class_creator.create_class_instances(all_models=True, **kwargs_model)
+        self._image2SourceMapping = Image2SourceMapping(lensModel=self._lens_model_class,
+                                                        sourceModel=self._source_model_class)
 
         if kwargs_fixed_lens is None:
             kwargs_fixed_lens = [{} for i in range(len(self._lens_model_list))]
@@ -172,9 +195,14 @@ class Param(object):
             self._solver = False
         else:
             self._solver = True
-            self._solver_module = Solver(solver_type=self._solver_type, lensModel=lens_model_class,
+            self._solver_module = Solver(solver_type=self._solver_type, lensModel=self._lens_model_class,
                                          num_images=self._num_images)
 
+        source_model_list = self._source_light_model_list
+        if (len(source_model_list) != 1 or source_model_list[0] not in ['SLIT_STARLETS', 'SLIT_STARLETS_GEN2']):
+            # source_grid_offset only defined for source profiles compatible with pixel-based solver
+            source_grid_offset = False
+
         self._joint_extinction_with_lens_light = joint_extinction_with_lens_light
         # fix parameters joint within the same model types
         kwargs_fixed_lens_updated = self._add_fixed_lens(kwargs_fixed_lens, kwargs_lens_init)
@@ -209,14 +237,14 @@ class Param(object):
                                           kwargs_fixed=kwargs_fixed_special, num_scale_factor=self._num_scale_factor,
                                           kwargs_lower=kwargs_lower_special, kwargs_upper=kwargs_upper_special,
                                           point_source_offset=self._point_source_offset, num_images=self._num_images,
-                                          source_size=source_size, num_tau0=num_tau0)
+                                          source_size=source_size, num_tau0=num_tau0, num_z_sampling=num_z_sampling,
+                                          source_grid_offset=source_grid_offset)
         for lens_source_joint in self._joint_lens_with_source_light:
             i_source = lens_source_joint[0]
             if i_source in self._image_plane_source_list:
                 raise ValueError("linking a source light model with a lens model AND simultaneously parameterizing the"
                                  " source position in the image plane is not valid!")
 
-
     @property
     def num_point_source_images(self):
         return self._num_images
@@ -237,16 +265,19 @@ class Param(object):
         kwargs_source, i = self.souceParams.getParams(args, i)
         kwargs_lens_light, i = self.lensLightParams.getParams(args, i)
         kwargs_ps, i = self.pointSourceParams.getParams(args, i)
-        kwargs_special, i = self.specialParams.getParams(args, i)
+        kwargs_special, i = self.specialParams.get_params(args, i)
         kwargs_extinction, i = self.extinctionParams.getParams(args, i)
+        self._update_lens_model(kwargs_special)
         # update lens_light joint parameters
         kwargs_lens_light = self._update_lens_light_joint_with_point_source(kwargs_lens_light, kwargs_ps)
-        kwargs_lens_light = self._update_joint_param(kwargs_lens_light, kwargs_lens_light, self._joint_lens_light_with_lens_light)
+        kwargs_lens_light = self._update_joint_param(kwargs_lens_light, kwargs_lens_light,
+                                                     self._joint_lens_light_with_lens_light)
         # update lens_light joint with lens model parameters
         kwargs_lens = self._update_joint_param(kwargs_lens_light, kwargs_lens, self._joint_lens_with_light)
         kwargs_lens = self._update_joint_param(kwargs_source, kwargs_lens, self._joint_lens_with_source_light)
         # update extinction model with lens light model
-        kwargs_extinction = self._update_joint_param(kwargs_lens_light, kwargs_extinction, self._joint_extinction_with_lens_light)
+        kwargs_extinction = self._update_joint_param(kwargs_lens_light, kwargs_extinction,
+                                                     self._joint_extinction_with_lens_light)
         # update lens model joint parameters (including scaling)
         kwargs_lens = self._update_joint_param(kwargs_lens, kwargs_lens, self._joint_lens_with_lens)
         kwargs_lens = self.update_lens_scaling(kwargs_special, kwargs_lens)
@@ -255,12 +286,11 @@ class Param(object):
             x_pos, y_pos = kwargs_ps[0]['ra_image'], kwargs_ps[0]['dec_image']
             kwargs_lens = self._solver_module.update_solver(kwargs_lens, x_pos, y_pos)
         # update source joint with point source
-        kwargs_source = self._update_source_joint_with_point_source(kwargs_lens, kwargs_source, kwargs_ps, kwargs_special,
-                                                                        image_plane=bijective)
+        kwargs_source = self._update_source_joint_with_point_source(kwargs_lens, kwargs_source, kwargs_ps,
+                                                                    kwargs_special, image_plane=bijective)
         # update source joint with source
         kwargs_source = self._update_joint_param(kwargs_source, kwargs_source, self._joint_source_with_source)
         # optional revert lens_scaling for bijective
-
         if bijective is True:
             kwargs_lens = self.update_lens_scaling(kwargs_special, kwargs_lens, inverse=True)
         kwargs_return = {'kwargs_lens': kwargs_lens, 'kwargs_source': kwargs_source,
@@ -274,6 +304,10 @@ class Param(object):
         inverse of getParam function
         :param kwargs_lens: keyword arguments depending on model options
         :param kwargs_source: keyword arguments depending on model options
+        :param kwargs_lens_light: lens light model keyword argument list
+        :param kwargs_ps: point source model keyword argument list
+        :param kwargs_special: special keyword arguments
+        :param kwargs_extinction: extinction model keyword argument list
         :return: tuple of parameters
         """
 
@@ -281,7 +315,7 @@ class Param(object):
         args += self.souceParams.setParams(kwargs_source)
         args += self.lensLightParams.setParams(kwargs_lens_light)
         args += self.pointSourceParams.setParams(kwargs_ps)
-        args += self.specialParams.setParams(kwargs_special)
+        args += self.specialParams.set_params(kwargs_special)
         args += self.extinctionParams.setParams(kwargs_extinction)
         return args
 
@@ -309,23 +343,23 @@ class Param(object):
 
         :return: number of parameters involved (int)
         """
-        num, list = self.lensParams.num_param()
+        num, name_list = self.lensParams.num_param()
         _num, _list = self.souceParams.num_param()
         num += _num
-        list += _list
+        name_list += _list
         _num, _list = self.lensLightParams.num_param()
         num += _num
-        list += _list
+        name_list += _list
         _num, _list = self.pointSourceParams.num_param()
         num += _num
-        list += _list
+        name_list += _list
         _num, _list = self.specialParams.num_param()
         num += _num
-        list += _list
+        name_list += _list
         _num, _list = self.extinctionParams.num_param()
         num += _num
-        list += _list
-        return num, list
+        name_list += _list
+        return num, name_list
 
     def num_param_linear(self):
         """
@@ -342,9 +376,10 @@ class Param(object):
         """
         maps the image plane position definition of the source plane
 
-        :param kwargs_source:
-        :param kwargs_lens:
-        :return:
+        :param kwargs_source: source light model keyword argument list
+        :param kwargs_lens: lens model keyword argument list
+        :param image_plane: boolean, if True, does not up map image plane parameters to source plane
+        :return: source light model keyword arguments with mapped position arguments from image to source plane
         """
         kwargs_source_copy = copy.deepcopy(kwargs_source)
         for i, kwargs in enumerate(kwargs_source_copy):
@@ -366,7 +401,7 @@ class Param(object):
                 y_mapped = kwargs_ps[i_point_source]['dec_source']
             else:
                 x_pos, y_pos = kwargs_ps[i_point_source]['ra_image'], kwargs_ps[i_point_source]['dec_image']
-                #x_pos, y_pos = self.real_image_positions(x_pos, y_pos, kwargs_special)
+                # x_pos, y_pos = self.real_image_positions(x_pos, y_pos, kwargs_special)
                 x_mapped, y_mapped = self._image2SourceMapping.image2source(x_pos, y_pos, kwargs_lens_list,
                                                                             index_source=k_source)
             for param_name in param_list:
@@ -401,7 +436,7 @@ class Param(object):
         :param kwargs_list_1: list of keyword arguments
         :param kwargs_list_2: list of keyword arguments
         :param joint_setting_list: [[i_1, k_2, ['param_name1', 'param_name2', ...]], [...], ...]
-        :return: udated kwargs_list_2 with arguments from kwargs_list_1 as defined in joint_setting_list
+        :return: updated kwargs_list_2 with arguments from kwargs_list_1 as defined in joint_setting_list
         """
         for setting in joint_setting_list:
             i_1, k_2, param_list = setting
@@ -428,11 +463,10 @@ class Param(object):
         """
         multiplies the scaling parameters of the profiles
 
-        :param args:
-        :param kwargs_lens:
-        :param i:
-        :param inverse:
-        :return:
+        :param kwargs_special: keyword arguments of the 'special' arguments
+        :param kwargs_lens: lens model keyword argument list
+        :param inverse: bool, if True, performs the inverse lens scaling for bijective transforms
+        :return: updated lens model keyword argument list
         """
         kwargs_lens_updated = copy.deepcopy(kwargs_lens)
         if self._mass_scaling is False:
@@ -463,12 +497,59 @@ class Param(object):
             kwargs_fixed_update = self._solver_module.add_fixed_lens(kwargs_fixed_update, kwargs_init)
         return kwargs_fixed_update
 
+    def update_kwargs_model(self, kwargs_special):
+        """
+        updates model keyword arguments with redshifts being sampled
+
+        :param kwargs_special: keyword arguments from SpecialParam() class return of sampling arguments
+        :return: kwargs_model, bool (True if kwargs_model has changed, else False)
+        """
+        if self._num_z_sampling == 0:
+            return self._kwargs_model, False
+        z_samples = kwargs_special.get('z_sampling')
+        lens_redshift_list = copy.deepcopy(self._lens_redshift_list)
+        if not(self._lens_redshift_list is None or self._lens_redshift_sampling_indexes is None):
+            # iterate through index lists
+            for i, index in enumerate(self._lens_redshift_sampling_indexes):
+                # update redshifts of lens and source redshift list in new form
+                if index > -1:
+                    lens_redshift_list[i] = z_samples[index]
+        source_redshift_list = copy.deepcopy(self._source_redshift_list)
+        if not (self._source_redshift_list is None or self._source_redshift_sampling_indexes is None):
+            # iterate through index lists
+            for i, index in enumerate(self._source_redshift_sampling_indexes):
+                # update redshifts of lens and source redshift list in new form
+                if index > -1:
+                    source_redshift_list[i] = z_samples[index]
+        # update lens model and source model classes
+        kwargs_model = copy.deepcopy(self._kwargs_model)
+        kwargs_model['lens_redshift_list'] = lens_redshift_list
+        kwargs_model['source_redshift_list'] = source_redshift_list
+        return kwargs_model, True
+
+    def _update_lens_model(self, kwargs_special):
+        """
+        updates lens model instance of this class (and all class instances related to it) when an update to the
+        modeled redshifts of the deflector and/or source planes are made
+
+        :param kwargs_special: keyword arguments from SpecialParam() class return of sampling arguments
+        :return: None, internal calls instance updated
+        """
+        kwargs_model, update_bool = self.update_kwargs_model(kwargs_special)
+        if update_bool is True:
+            # TODO: this class instances are effectively duplicated in the likelihood module and may cause a lot of overhead
+            # in the calculation as the instances are re-generated every step, and even so doing it twice!
+            self._lens_model_class, self._source_model_class, _, _, _ = class_creator.create_class_instances(
+                all_models=True, **kwargs_model)
+            self._image2SourceMapping = Image2SourceMapping(lensModel=self._lens_model_class,
+                                                            sourceModel=self._source_model_class)
+
     def check_solver(self, kwargs_lens, kwargs_ps):
         """
         test whether the image positions map back to the same source position
-        :param kwargs_lens:
-        :param kwargs_ps:
-        :return: Euclidean distance between the rayshooting of the image positions
+        :param kwargs_lens: lens model keyword argument list
+        :param kwargs_ps: point source model keyword argument list
+        :return: Euclidean distance between the ray-shooting of the image positions
         """
         if self._solver is True:
             image_x, image_y = kwargs_ps[0]['ra_image'], kwargs_ps[0]['dec_image']
@@ -477,28 +558,6 @@ class Param(object):
         else:
             return 0
 
-    def check_positive_flux(self, kwargs_source, kwargs_lens_light, kwargs_ps):
-        pos_bool_ps = self.pointSourceParams.check_positive_flux(kwargs_ps)
-        pos_bool_source = self.souceParams.check_positive_flux_profile(kwargs_source)
-        pos_bool_lens_light = self.lensLightParams.check_positive_flux_profile(kwargs_lens_light)
-        if pos_bool_ps is True and pos_bool_source is True and pos_bool_lens_light is True:
-            return True
-        else:
-            return False
-
-    #def real_image_positions(self, x, y, kwargs_special):
-    #    """
-
-     #   :param kwargs_ps: point source kwargs
-     #   :param kwargs_special: special kwargs (or other kwargs)
-     #   :return: position where time delays are evaluated and solver is solved for
-     #   """
-     #   if self._point_source_offset is True:
-     #       delta_x, delta_y = kwargs_special['delta_x_image'], kwargs_special['delta_y_image']
-     #       return x + delta_x, y + delta_y
-     #   else:
-     #       return x, y
-
     def print_setting(self):
         """
         prints the setting of the parameter class
