@@ -10,8 +10,9 @@ from lenstronomy.ImSim.image_linear_solve import ImageLinearFit
 def create_class_instances(lens_model_list=[], z_lens=None, z_source=None, lens_redshift_list=None,
                            multi_plane=False, observed_convention_index=None, source_light_model_list=[],
                            lens_light_model_list=[], point_source_model_list=[], fixed_magnification_list=None,
-                           additional_images_list=None, min_distance=0.01, search_window=5, precision_limit=10**(-10),
-                           num_iter_max=100, source_deflection_scaling_list=None, source_redshift_list=None, cosmo=None,
+                           flux_from_point_source_list=None,
+                           additional_images_list=None, kwargs_lens_eqn_solver=None,
+                           source_deflection_scaling_list=None, source_redshift_list=None, cosmo=None,
                            index_lens_model_list=None, index_source_light_model_list=None,
                            index_lens_light_model_list=None, index_point_source_model_list=None,
                            optical_depth_model_list=[], index_optical_depth_model_list=None,
@@ -29,11 +30,11 @@ def create_class_instances(lens_model_list=[], z_lens=None, z_source=None, lens_
     :param lens_light_model_list:
     :param point_source_model_list:
     :param fixed_magnification_list:
+    :param flux_from_point_source_list: list of bools (optional), if set, will only return image positions
+         (for imaging modeling) for the subset of the point source lists that =True. This option enables to model
     :param additional_images_list:
-    :param min_distance:
-    :param search_window:
-    :param precision_limit:
-    :param num_iter_max:
+    :param kwargs_lens_eqn_solver: keyword arguments specifying the numerical settings for the lens equation solver
+         see LensEquationSolver() class for details
     :param source_deflection_scaling_list:
     :param source_redshift_list:
     :param cosmo: astropy.cosmology instance
@@ -110,9 +111,10 @@ def create_class_instances(lens_model_list=[], z_lens=None, z_source=None, lens_
             additional_images_list_i = [additional_images_list[k] for k in index_point_source_model_list[band_index]]
     point_source_class = PointSource(point_source_type_list=point_source_model_list_i, lensModel=lens_model_class,
                                      fixed_magnification_list=fixed_magnification_list_i,
-                                     additional_images_list=additional_images_list_i, min_distance=min_distance,
-                                     search_window=search_window, precision_limit=precision_limit,
-                                     num_iter_max=num_iter_max, magnification_limit=point_source_magnification_limit)
+                                     flux_from_point_source_list=flux_from_point_source_list,
+                                     additional_images_list=additional_images_list_i,
+                                     magnification_limit=point_source_magnification_limit,
+                                     kwargs_lens_eqn_solver=kwargs_lens_eqn_solver)
     if tau0_index_list is None:
         tau0_index = 0
     else:
@@ -143,7 +145,7 @@ def create_image_model(kwargs_data, kwargs_psf, kwargs_numerics, kwargs_model, l
 
 
 def create_im_sim(multi_band_list, multi_band_type, kwargs_model, bands_compute=None, likelihood_mask_list=None,
-                  band_index=0):
+                  band_index=0, kwargs_pixelbased=None):
     """
 
 
@@ -153,6 +155,8 @@ def create_im_sim(multi_band_list, multi_band_type, kwargs_model, bands_compute=
     - 'linear-joint': linear amplitudes ae jointly inferred
     - 'single-band': single band
 
+    :param kwargs_pixelbased: keyword arguments with various settings related to the pixel-based solver (see SLITronomy documentation)
+
     :return: MultiBand class instance
     """
 
@@ -165,7 +169,7 @@ def create_im_sim(multi_band_list, multi_band_type, kwargs_model, bands_compute=
     elif multi_band_type == 'single-band':
         from lenstronomy.ImSim.MultiBand.single_band_multi_model import SingleBandMultiModel
         multiband = SingleBandMultiModel(multi_band_list, kwargs_model, likelihood_mask_list=likelihood_mask_list,
-                                         band_index=band_index)
+                                         band_index=band_index, kwargs_pixelbased=kwargs_pixelbased)
     else:
         raise ValueError("type %s is not supported!" % multi_band_type)
     return multiband
