@@ -32,6 +32,7 @@ class FittingSequence(object):
         """
         self.kwargs_data_joint = kwargs_data_joint
         self.multi_band_list = kwargs_data_joint.get('multi_band_list', [])
+        self.multi_band_type = kwargs_data_joint.get('multi_band_type', 'single-band')
         self._verbose = verbose
         self._mpi = mpi
         self._updateManager = MultiBandUpdateManager(kwargs_model, kwargs_constraints, kwargs_likelihood, kwargs_params,
@@ -343,7 +344,8 @@ class FittingSequence(object):
         return output
 
     def psf_iteration(self, num_iter=10, no_break=True, stacking_method='median', block_center_neighbour=0,
-                      keep_psf_error_map=True, psf_symmetry=1, psf_iter_factor=1, verbose=True, compute_bands=None):
+                      keep_psf_error_map=True, psf_symmetry=1, psf_iter_factor=1, verbose=True,
+                      compute_bands=None):
         """
         iterative PSF reconstruction
 
@@ -361,7 +363,7 @@ class FittingSequence(object):
         kwargs_model = self._updateManager.kwargs_model
         kwargs_likelihood = self._updateManager.kwargs_likelihood
         likelihood_mask_list = kwargs_likelihood.get('image_likelihood_mask_list', None)
-        #param_class = self.param_class
+        kwargs_pixelbased = kwargs_likelihood.get('kwargs_pixelbased', None)
         kwargs_temp = self.best_fit(bijective=False)
         if compute_bands is None:
             compute_bands = [True] * len(self.multi_band_list)
@@ -370,13 +372,14 @@ class FittingSequence(object):
             if compute_bands[band_index] is True:
                 kwargs_psf = self.multi_band_list[band_index][1]
                 image_model = SingleBandMultiModel(self.multi_band_list, kwargs_model,
-                                                   likelihood_mask_list=likelihood_mask_list, band_index=band_index)
+                                                   likelihood_mask_list=likelihood_mask_list, band_index=band_index,
+                                                   kwargs_pixelbased=kwargs_pixelbased)
                 psf_iter = PsfFitting(image_model_class=image_model)
                 kwargs_psf = psf_iter.update_iterative(kwargs_psf, kwargs_params=kwargs_temp, num_iter=num_iter,
                                                        no_break=no_break, stacking_method=stacking_method,
                                                        block_center_neighbour=block_center_neighbour,
-                                                       keep_psf_error_map=keep_psf_error_map,
-                 psf_symmetry=psf_symmetry, psf_iter_factor=psf_iter_factor, verbose=verbose)
+                                                       keep_psf_error_map=keep_psf_error_map, psf_symmetry=psf_symmetry,
+                                                       psf_iter_factor=psf_iter_factor, verbose=verbose)
                 self.multi_band_list[band_index][1] = kwargs_psf
         return 0
 
@@ -397,10 +400,6 @@ class FittingSequence(object):
         kwargs_model = self._updateManager.kwargs_model
         kwargs_likelihood = self._updateManager.kwargs_likelihood
         likelihood_mask_list = kwargs_likelihood.get('image_likelihood_mask_list', None)
-        #param_class = self.param_class
-        #lens_temp, source_temp, lens_light_temp, ps_temp, cosmo_temp = self._updateManager.parameter_state
-        #lens_updated = param_class.update_lens_scaling(cosmo_temp, lens_temp)
-        #source_updated = param_class.image2source_plane(source_temp, lens_updated)
         kwargs_temp = self.best_fit(bijective=False)
         if compute_bands is None:
             compute_bands = [True] * len(self.multi_band_list)
