@@ -33,7 +33,7 @@ class TestLensModel(object):
         x,y = 0.2,1
         kwargs = [{'alpha_Rs':1, 'Rs': 0.5, 'center_x':0, 'center_y': 0}]
         value = lensModel.potential(x,y,kwargs)
-        nfw_interp = NFW(interpol=True, lookup=True)
+        nfw_interp = NFW(interpol=True)
         value_interp_lookup = nfw_interp.function(x, y, **kwargs[0])
         npt.assert_almost_equal(value, value_interp_lookup, decimal=4)
 
