@@ -235,7 +235,7 @@ class TestNumericsProfile(object):
         self.assert_differentials(lens_model, kwargs)
 
     def test_EPL(self):
-        kwargs = {'theta_E': 2., 'e1': 0.1, 'e2': 0., 't': 1.23}
+        kwargs = {'theta_E': 2., 'e1': 0.1, 'e2': 0., 'gamma': 2.13}
         lens_model = ['EPL']
         self.assert_differentials(lens_model, kwargs)
 
@@ -275,6 +275,31 @@ class TestNumericsProfile(object):
         kwargs = {'lambda_approx': 1.1, 'r_core': 8}
         lens_model = ['CORED_DENSITY_2_MST']
         self.assert_differentials(lens_model, kwargs)
+        
+    def test_const_mag_positive(self):
+        kwargs = {'mu_r': 1, 'mu_t': 10, 'parity': 1, 'phi_G': 0.1}
+        lens_model = ['CONST_MAG']
+        self.assert_differentials(lens_model, kwargs)
+        
+    def test_const_mag_negative(self):
+        kwargs = {'mu_r': 1, 'mu_t': 10, 'parity': -1, 'phi_G': 0.1}
+        lens_model = ['CONST_MAG']
+        self.assert_differentials(lens_model, kwargs)
+        
+    def test_nie_potential(self):
+        kwargs = {'theta_E':2. , 'theta_c':1. , 'e1': 0.1, 'e2': 0.1}
+        lens_model = ['NIE_POTENTIAL']
+        self.assert_differentials(lens_model, kwargs)
+    def test_multipole(self):
+        kwargs = {'m':4, 'a_m':0.05, 'phi_m':0.1, 'center_x':0., 'center_y':0.}
+        lens_model = ['MULTIPOLE']
+        self.assert_differentials(lens_model,kwargs,potential=True)
+        kwargs = {'m': 2, 'a_m': 0.1, 'phi_m': 0.05, 'center_x': 0., 'center_y': 0.}
+        lens_model = ['MULTIPOLE']
+        self.assert_differentials(lens_model, kwargs, potential=True)
+        kwargs = {'m': 3, 'a_m': 0.07, 'phi_m': 0., 'center_x': -0.01, 'center_y': -0.5}
+        lens_model = ['MULTIPOLE']
+        self.assert_differentials(lens_model, kwargs, potential=True)
 
 
 if __name__ == '__main__':
