@@ -163,6 +163,31 @@ def test_image2array2image():
     assert image_new[1, 2] == image[1, 2]
 
 
+def test_array2cube():
+    array = np.linspace(1, 200, 200)
+    image = util.array2cube(array, 2, 100)
+    assert image[0][9][9] == 100
+    assert image[1][0][9] == 110
+
+
+def test_cube2array():
+    sube = np.zeros((2, 10, 10))
+    sube[1, 2, 2] = 1
+    array = util.cube2array(sube)
+    assert array[122] == 1
+
+
+def test_cube2array2cube():
+    cube = np.zeros((2, 10, 10))
+    ns, nx, ny = np.shape(cube)
+    assert nx == ny  # condition required
+    nxy = nx*ny
+    cube[1, 2, 2] = 1
+    array = util.cube2array(cube)
+    cube_new = util.array2cube(array, ns, nxy)
+    assert cube_new[1, 2, 2] == cube[1, 2, 2]
+
+
 def test_get_axes():
     numPix = 11
     deltapix = 0.1
@@ -346,6 +371,9 @@ class TestRaise(unittest.TestCase):
         with self.assertRaises(ValueError):
             array = np.ones(5)
             util.array2image(array)
+        with self.assertRaises(ValueError):
+            array = np.ones((2, 2))
+            util.array2cube(array, 2, 2)
         with self.assertRaises(ValueError):
             x, y = np.ones(6), np.ones(6)
             util.get_axes(x, y)
